# Changelog

All notable changes to this project will be documented in this file.

## [0.1.1] - 2024-12-14

### 🐛 Bug Fixes

- Check command now actually checks git history (#59)

<!-- generated by git-cliff -->
